import React from 'react';
import { UseQueryResult } from 'react-query';
export interface AuthProviderConfig<User, Error> {
    key?: string;
    loadUser: (data: unknown) => Promise<User>;
    loginFn: (data: unknown) => Promise<User>;
    registerFn: (data: unknown) => Promise<User>;
    logoutFn: () => Promise<any>;
    renderLoader?: () => React.ReactNode;
    renderError?: (error: Error) => React.ReactNode;
    onLoginSuccess?: (user: User) => void | Promise<void>;
    onRegisterSuccess?: (user: User) => void | Promise<void>;
    onLogoutSuccess?: () => void | Promise<void>;
    onLoginError?: (error: Error) => void;
    onRegisterError?: (error: Error) => void;
    onLogoutError?: (error: Error) => void;
}
export interface AuthContextValue<User, Error> {
    user: User | undefined;
    login: (data: any) => Promise<User>;
    logout: () => Promise<boolean>;
    register: (data: any) => Promise<User>;
    refetch: (options: {
        throwOnError: boolean;
        cancelRefetch: boolean;
    }) => Promise<UseQueryResult>;
    error: Error | null;
}
export interface AuthProviderProps {
    children: React.ReactNode;
}
export declare function initReactQueryAuth<User = unknown, Error = unknown>(config: AuthProviderConfig<User, Error>): {
    AuthProvider: ({ children }: AuthProviderProps) => JSX.Element;
    useAuth: () => AuthContextValue<User, Error>;
};
